@@ -144,8 +144,6 @@ class PostgreSQLUtils:
                 password=self.password,
                 port=self.port,
             )
-            # 连接建立时初始化本连接周期的已重置表集合
-            self._sequence_reset_tables = set()
             return True
         except Exception as e:
             logging.error(f"数据库连接失败: {e}")
@@ -236,9 +234,6 @@ class PostgreSQLUtils:
         if self.connection and not self.connection.closed:
             self.connection.close()
             self.connection = None
-        # 断开连接时清空已重置表集合
-        if hasattr(self, '_sequence_reset_tables'):
-            self._sequence_reset_tables.clear()
 
     def find(
         self, sql: str, to_json: bool = False, *args, **kwargs
@@ -309,13 +304,6 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 仅在本连接周期内未重置过该表时重置序列
-        if not hasattr(self, '_sequence_reset_tables'):
-            self._sequence_reset_tables = set()
-        if table not in self._sequence_reset_tables:
-            self._reset_sequence_for_table(table)
-            self._sequence_reset_tables.add(table)
-
         # 处理字典类型的数据
         processed_data = self._process_data_for_insertion(data)
 
@@ -358,13 +346,6 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 仅在本连接周期内未重置过该表时重置序列
-        if not hasattr(self, '_sequence_reset_tables'):
-            self._sequence_reset_tables = set()
-        if table not in self._sequence_reset_tables:
-            self._reset_sequence_for_table(table)
-            self._sequence_reset_tables.add(table)
-
         # 处理所有数据中的字典类型
         processed_data_list = [
             self._process_data_for_insertion(data) for data in data_list
@@ -427,13 +408,6 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 仅在本连接周期内未重置过该表时重置序列
-        if not hasattr(self, '_sequence_reset_tables'):
-            self._sequence_reset_tables = set()
-        if table not in self._sequence_reset_tables:
-            self._reset_sequence_for_table(table)
-            self._sequence_reset_tables.add(table)
-
         # 处理字典类型的数据
         processed_data = self._process_data_for_insertion(data)
 
@@ -450,7 +424,9 @@ class PostgreSQLUtils:
             # 构建ON CONFLICT更新部分
             update_parts = []
             for column in columns:
-                if column != primary_key:  # 主键不更新
+                if (isinstance(conflict_key, list) and column not in conflict_key) or (
+                    isinstance(conflict_key, str) and column != conflict_key
+                ):
                     update_parts.append('"{}" = EXCLUDED."{}"'.format(column, column))
             update_clause = ", ".join(update_parts)
 
@@ -481,8 +457,6 @@ class PostgreSQLUtils:
             # 使用彩色打印显示错误信息
             self.cp.red(f"数据插入或更新失败: {e}")
             self.cp.yellow(f"错误数据: {processed_data}")
-            # logging.error(f"数据插入或更新失败: {e}")
-            # logging.warning(f"错误数据: {processed_data}")
             self.connection.rollback()
             return False
 
